@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the emotional sentiment of text
 
-our $VERSION = '0.1102';
+our $VERSION = '0.12';
 
 use Moo;
 use strictures 2;
@@ -48,8 +48,10 @@ sub _build_stemmer {
     try {
         require WordNet::QueryData;
         require WordNet::stem;
+
         my $wn      = WordNet::QueryData->new();
         my $stemmer = WordNet::stem->new($wn);
+
         return $stemmer;
     }
     catch {
@@ -79,6 +81,42 @@ has nrc_scores => (
 );
 
 
+has positive => (
+    is       => 'rw',
+    init_arg => undef,
+    lazy     => 1,
+    builder  => 1,
+);
+
+sub _build_positive {
+    return Lingua::EN::Opinion::Positive->new;
+}
+
+
+has negative => (
+    is       => 'rw',
+    init_arg => undef,
+    lazy     => 1,
+    builder  => 1,
+);
+
+sub _build_negative {
+    return Lingua::EN::Opinion::Negative->new;
+}
+
+
+has emotion => (
+    is       => 'rw',
+    init_arg => undef,
+    lazy     => 1,
+    builder  => 1,
+);
+
+sub _build_emotion {
+    return Lingua::EN::Opinion::Emotion->new;
+}
+
+
 sub analyze {
     my ($self) = @_;
 
@@ -92,9 +130,6 @@ sub analyze {
 
     my @scores;
 
-    my $positive = Lingua::EN::Opinion::Positive->new();
-    my $negative = Lingua::EN::Opinion::Negative->new();
-
     for my $sentence ( @sentences ) {
         my @words = _tokenize($sentence);
 
@@ -103,8 +138,8 @@ sub analyze {
         for my $word ( @words ) {
             $word = $self->_stemword($word);
 
-            $score += exists $positive->wordlist->{$word} ? 1
-                    : exists $negative->wordlist->{$word} ? -1 : 0;
+            $score += exists $self->positive->wordlist->{$word} ? 1
+                    : exists $self->negative->wordlist->{$word} ? -1 : 0;
         }
 
         push @scores, $score;
@@ -146,8 +181,6 @@ sub nrc_sentiment {
 
     my @scores;
 
-    my $emotion = Lingua::EN::Opinion::Emotion->new();
-
     for my $sentence ( @sentences ) {
         my @words = _tokenize($sentence);
 
@@ -156,9 +189,9 @@ sub nrc_sentiment {
         for my $word ( @words ) {
             $word = $self->_stemword($word);
 
-            if ( exists $emotion->wordlist->{$word} ) {
-                for my $key ( keys %{ $emotion->wordlist->{$word} } ) {
-                    $score->{$key} += $emotion->wordlist->{$word}{$key};
+            if ( exists $self->emotion->wordlist->{$word} ) {
+                for my $key ( keys %{ $self->emotion->wordlist->{$word} } ) {
+                    $score->{$key} += $self->emotion->wordlist->{$word}{$key};
                 }
             }
         }
@@ -178,13 +211,10 @@ sub get_word {
 
     $word = $self->_stemword($word);
 
-    my $positive = Lingua::EN::Opinion::Positive->new();
-    my $negative = Lingua::EN::Opinion::Negative->new();
-
-    return exists $positive->wordlist->{$word} || exists $negative->wordlist->{$word}
+    return exists $self->positive->wordlist->{$word} || exists $self->negative->wordlist->{$word}
         ? {
-            positive => exists $positive->wordlist->{$word} ? 1 : 0,
-            negative => exists $negative->wordlist->{$word} ? 1 : 0,
+            positive => exists $self->positive->wordlist->{$word} ? 1 : 0,
+            negative => exists $self->negative->wordlist->{$word} ? 1 : 0,
         }
         : undef;
 }
@@ -195,10 +225,8 @@ sub nrc_get_word {
 
     $word = $self->_stemword($word);
 
-    my $emotion = Lingua::EN::Opinion::Emotion->new();
-
-    return exists $emotion->wordlist->{$word}
-        ? $emotion->wordlist->{$word}
+    return exists $self->emotion->wordlist->{$word}
+        ? $self->emotion->wordlist->{$word}
         : undef;
 }
 
@@ -265,7 +293,7 @@ Lingua::EN::Opinion - Measure the emotional sentiment of text
 
 =head1 VERSION
 
-version 0.1102
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -305,6 +333,10 @@ A text string to analyze instead of a text file.
 
 Boolean flag to indicate that word stemming should take place.
 
+For example, "horses" becomes "horse" and "hooves" becomes "hoof."
+
+This is the proper way to use this module.
+
 =head2 stemmer
 
 Require the L<WordNet::QueryData> and L<WordNet::stem> modules to stem each word
@@ -326,6 +358,18 @@ Computed result.
 
 Computed result.
 
+=head2 positive
+
+Computed result.
+
+=head2 negative
+
+Computed result.
+
+=head2 emotion
+
+Computed result.
+
 =head1 METHODS
 
 =head2 new()
